<?php
/**
 * @file
 * Drop Jobs Hotsite Rules integration.
 */

/**
 * Implements hook_rules_event_info().
 *
 * Defines rules events.
 */
function drop_jobs_hotsite_rules_event_info() {
  $events = array();

  // For the sake of convenience.
  $defaults = array(
    'group' => t('Drop Jobs Hotsite'),
  );

  // Candidate applies to a Job.
  $events['drop_jobs_hotsite_enable'] = array(
    'label' => t('Hotsite is enabled.'),
  ) + $defaults;

  // Candidate removes Job hotsite.
  $events['drop_jobs_hotsite_disable'] = array(
    'label' => t('Hotsite is disabled.'),
  ) + $defaults;

  return $events;
}

/**
 * Implements hook_rules_condition_info().
 *
 * Define rules conditions.
 */
function hotsite_rules_condition_info() {
  $conditions = array();

  $conditions['hotsite_enabled'] = array(
    'group' => t('Drop Jobs Hotsite'),
    'label' => t("Hotsite is enabled."),
    'base' => 'hotsite_condition_enabled',
  );

  return $conditions;
}

/**
 * Implements hook_rules_action_info().
 *
 * Define rules actions.
 */
function hotsite_rules_action_info() {
  $actions = array();

  // For convenience.
  $defaults = array(
    'group' => t('Drop Jobs Hotsite'),
    'access callback' => 'drop_jobs_hotsite_rules_access',
  );

  // Enable hotsite mode.
  $actions['drop_jobs_hotsite_enable'] = array(
    'label' => t('Enable hotsite mode.'),
    'base' => 'drop_jobs_hotsite_enable',
    ) + $defaults;

  // Disable hotsite mode.
  $actions['drop_jobs_hotsite_disable'] = array(
    'label' => t('Disable hotsite mode.'),
    'base' => 'drop_jobs_hotsite_disable',
    ) + $defaults;

  return $actions;
}

/**
 * Rules condition callback.
 * Checks whether Hotsite mode is enabled.
 *
 * @return boolean
 *   Whether Hotsite mode is enabled.
 *
 * @see hotsite_rules_condition_info()
 */
function hotsite_condition_enabled() {
  return variable_get_value('drop_jobs_hotsite_enabled');
}

/**
 * Access callback.
 *
 * @see hotsite_rules_event_info()
 * @see hotsite_rules_action_inf()
 */
function hotsite_rules_access($type, $name) {
  if ($type == 'event' || $type == 'condition') {
    return user_access('administer drop_jobs_hotsite');
  }
}